@@ -1,6 +1,6 @@
 package Yukki::Model::File;
-BEGIN {
-  $Yukki::Model::File::VERSION = '0.112770';
+{
+  $Yukki::Model::File::VERSION = '0.121700';
 }
 use 5.12.1;
 use Moose;
@@ -113,13 +113,13 @@ sub title {
 
     if ($self->filetype eq 'yukki') {
         LINE: for my $line ($self->fetch) {
-            if ($line =~ /:/) {
+            if ($line =~ /^#\s*(.*)$/) {
+                return $1;
+            }
+            elsif ($line =~ /:/) {
                 my ($name, $value) = split m{\s*:\s*}, $line, 2;
                 return $value if lc($name) eq 'title';
             }
-            elsif ($line =~ /^#\s*(.*)$/) {
-                return $1;
-            }
             else {
                 last LINE;
             }
@@ -345,7 +345,7 @@ Yukki::Model::File - the model for loading and saving files in the wiki
 
 =head1 VERSION
 
-version 0.112770
+version 0.121700
 
 =head1 SYNOPSIS
 
@@ -556,7 +556,7 @@ Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Qubling Software LLC.
+This software is copyright (c) 2012 by Qubling Software LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
